#
# spec file for package kdevelop5-plugin-php
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname   kdev-php
Name:           kdevelop5-plugin-php
Version:        5.6.1
Release:        bp153.2.2.4
Summary:        PHP plugin for Kdevelop5 Integrated Development Environment
License:        GPL-2.0-or-later
Group:          Development/Tools/IDE
URL:            https://www.kdevelop.org
Source0:        https://download.kde.org/stable/kdevelop/%{version}/src/%{rname}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  kcmutils-devel
BuildRequires:  kdevelop5-pg-qt
BuildRequires:  kdevplatform-devel
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel
BuildRequires:  ktexteditor-devel
BuildRequires:  pkgconfig
BuildRequires:  threadweaver-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
Requires:       kdevelop5
Recommends:     %{name}-lang
Conflicts:      kdevelop4-plugin-php

%description
PHP plugin for Kdevelop Integrated Development Environment

This plugin enables support for the following features for developing
web applications in PHP using Kdevelop5.

  * PHP built-in functions, classes, constants, superglobals
  * user-defined functions, classes, constants, superglobals, variables, etc.
  * proper code completion for objects which respects access modifiers (private, public, protected) and differentiates between static/non-static members and methods
  * code completion for overridable and implementable functions inside classes
  * hints in the argument list of function- and method class
  * sane code completion after keywords such as extends, implements, catch(), new, throw and some more

%package devel
Summary:        Development package for kdevelop5-plugin-php
Group:          Development/Tools/IDE
Requires:       kdevelop5-plugin-php = %{version}

%description devel
This package contains the development files needed in order to use the
kdevelop5-plugin-php API.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    packageand(bundle-lang-other:%{name})
# Language file conflicts
Conflicts:      kdevelop4-plugins-php
Conflicts:      kdevelop4-plugins-php-doc
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%setup -q -n %{rname}-%{version}

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %find_lang kdevphp %{name}.lang

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS HACKING TODO
%{_kf5_appstreamdir}/org.kde.kdev-php.metainfo.xml
%{_kf5_debugdir}/kdevphpsupport.categories
%{_kf5_libdir}/*.so*
%{_kf5_plugindir}/
%{_kf5_servicesdir}/
%{_kf5_sharedir}/kdev*/

%files devel
%license COPYING
%{_includedir}/kdev-php/
%{_kf5_cmakedir}/KDevPHP/

%files lang -f %{name}.lang

%changelog
* Wed Dec  9 2020 wbauer@tmo.at
- Update to 5.6.1
  * no code changes
* Tue Sep  8 2020 wbauer@tmo.at
- Update to 5.6.0
  * Update phpfunctions.php to phpdoc revision 350290
  * Support PHP 7.1's syntax for catching multiple exceptions
* Tue Jun  2 2020 wbauer@tmo.at
- Update to 5.5.2
  * Check type before accessing it (kde#421509)
* Tue May  5 2020 wbauer@tmo.at
- Update to 5.5.1
  * Fix a crash when showing the documentation popup
  * Update phpfunctions.php to phpdoc revision 349647
* Mon Feb  3 2020 wbauer@tmo.at
- Update to 5.5.0
  * Fix uses of function call parameters after closures
  * Add support for PHP 7.4's typed properties
  * Support importing functions and constants from other namespaces
    (kde#408609)
  * Fix rename of a variable (kde#317879)
  * Add support for "array of type"
  * Add support for class constant visibility
  * I18n: update message to new default
* Tue Jan  7 2020 wbauer@tmo.at
- Update to 5.4.6
  * Update phpfunctions.php to phpdoc revision 348802
* Mon Dec  2 2019 wbauer@tmo.at
- Update to 5.4.5
  * Update phpfunctions.php to phpdoc revision 34827
* Tue Nov  5 2019 wbauer@tmo.at
- Update to 5.4.4
  * no code changes
* Tue Oct 22 2019 wbauer@tmo.at
- Update to 5.4.3
  * Fix expressions using array constants (kde#405719)
  * Don't mark class constants as normal members
* Tue Sep  3 2019 wbauer@tmo.at
- Update to 5.4.2
  * no code changes
* Tue Aug 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.4.1
  * Update phpfunctions.php to phpdoc revision 347831
  * Switch few http URLs to https.
* Tue Aug  6 2019 wbauer@tmo.at
- New upstream release 5.4.0
  * Always set maximum file size for internal parse job
  * Bypass the 5 MB maximum file size limit for the
    phpfunctions.php internal file
  * Fix linking with ld.lld
* Thu Jul 18 2019 wbauer@tmo.at
- New upstream release 5.3.3
  * Use KDE_INSTALL_LOGGINGCATEGORIESDIR for kdebugsettings
    .categories file
  * Update phpfunctions.php to phpdoc revision 347011
  * Parse more function aliases
  * More special handling for mcrypt constants
  * Parse more class constants
  * Parse more constants
  * Parse constants under para
  * Parse more constants within tables
  * Parse url stat constants
  * Parse php token constants
  * Parse file upload constants
  * Parse constants under tables
  * Parse constants under section and within tables
  * Parse nl-langinfo constants
  * Parse constants split over multiple lists within one file
  * Fix function declarations with varargs
* Thu Mar  7 2019 wbauer@tmo.at
- New upstream release 5.3.2
  * no code changes
* Sat Dec 22 2018 wbauer@tmo.at
- New upstream release 5.3.1
  * Fix handling of array indexes after ClassNameReferences
    (kde#401278)
  * Fix syntax support for dynamic member access (kde#400294)
- Run spec-cleaner
* Wed Nov 14 2018 wbauer@tmo.at
- New upstream release 5.3.0
  * Much improved support for PHP Namespaces
  * Added support for Generators and Generator delegation
  * Updated and expanded the integrated documentation of PHP
    internals
  * Added support for PHP 7's context sensitive lexer
  * Install the parser as a library so it can be used by other
    projects (currently, umbrello can use it)
  * Improved type detection of object properties
  * Added support for the object typehint
  * Better support for ClassNameReferences (instanceof)
  * Expression syntax support improvements, particularly around
    'print'
  * Allow optional function parameters before non-optional ones
  * Added support for magic constants __DIR__ and __TRAIT__
- Add devel subpackage
- Remove unnecessary build requirements
* Tue Aug 21 2018 wbauer@tmo.at
- New upstream release 5.2.4
  * Determine correct type for relational and equality expressions
    (kde#305341)
  * Fix a bug with rescheduling jobs
* Fri May 25 2018 wbauer@tmo.at
- New upstream release 5.2.3 (5.2.2 has been skipped)
  * no code changes
- New upstream release 5.2.1
  * Fix a crash when showing navigation tooltip in PHP projects in
    some situations (kde#386969)
- New upstream release 5.2.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-520-released
  * Added support for new language features
  * Work on the type system
  * Bug fixes
- Mark license file as %%license instead of %%doc
* Tue Aug 29 2017 wbauer@tmo.at
- New upstream release 5.1.2
  * Fix a possible crash while parsing PHP code (kde#381123)
* Sat May 27 2017 wbauer@tmo.at
- New upstream release 5.1.1
  * Fix duchain unit tests
* Thu Mar 23 2017 wbauer@tmo.at
- New upstream release 5.1.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-510-released
* Sun Mar  5 2017 wbauer@tmo.at
- New upstream release 5.0.4
  * Update version number to 5.0.4
- Fix a typo in the package description
* Fri Dec  2 2016 wbauer@tmo.at
- New upstream release 5.0.3
  * no code changes
* Wed Nov 16 2016 wbauer@tmo.at
- New upstream release 5.0.2
  * no code changes
* Tue Oct  4 2016 lbeltrame@kde.org
- Remove translations that are no longer there
* Tue Oct  4 2016 lbeltrame@kde.org
- Add BuildRequires to QtConcurrent to fix build
* Mon Oct  3 2016 lbeltrame@kde.org
- New upstream release 5.0.1
  * Fix a crash in the PHP plugin when editing text in the line
    after a "TODO".
* Mon Sep 26 2016 lbeltrame@kde.org
- Tighten Conflicts even more for -lang file conflicts
* Mon Sep 26 2016 lbeltrame@kde.org
- Add Conflicts with kdevelop4-plugin-php (main package and docs)
* Wed Aug 24 2016 cgiboudeaux@gmx.com
- Update to 5.0.0
* Thu Jan 28 2016 tittiatcoke@gmail.com
- Initial package for the PHP plugin for Kdevelop based on Frameworks
  * KDevelop 5 Beta 3
